var searchData=
[
  ['plbool',['PLBOOL',['../plplot_8h.html#aeaedd6596f4fb4446c7fd5ad8f0e9673',1,'plplot.h']]],
  ['plbool_5fnc_5fscalar',['PLBOOL_NC_SCALAR',['../plplot_8h.html#ac129fb5e615fd75097cd6d387a2b2d23',1,'plplot.h']]],
  ['plbool_5fvector',['PLBOOL_VECTOR',['../plplot_8h.html#abedf6e0648c1ab84fd0092b85b2a3853',1,'plplot.h']]],
  ['plchar_5fmatrix',['PLCHAR_MATRIX',['../plplot_8h.html#a888f37cbad3cf274bd6e346fe9633e32',1,'plplot.h']]],
  ['plchar_5fnc_5fmatrix',['PLCHAR_NC_MATRIX',['../plplot_8h.html#af702cf66883379fbc3f483350f920867',1,'plplot.h']]],
  ['plchar_5fnc_5fscalar',['PLCHAR_NC_SCALAR',['../plplot_8h.html#aee8b6ca2305f2e90b458dfd81ac3c2c0',1,'plplot.h']]],
  ['plchar_5fnc_5fvector',['PLCHAR_NC_VECTOR',['../plplot_8h.html#aa5d13797fb9bcacfabb250bb5c200cf0',1,'plplot.h']]],
  ['plchar_5fvector',['PLCHAR_VECTOR',['../plplot_8h.html#a4451db36651890dcf3b5d5a34c464477',1,'plplot.h']]],
  ['pld_5fbop_5ffp',['plD_bop_fp',['../disptab_8h.html#ac0cfbf89d7f216b85a9b39735d15e63c',1,'disptab.h']]],
  ['pld_5feop_5ffp',['plD_eop_fp',['../disptab_8h.html#a060a50b2e40c2b8fa7aec9b9d04c2c1d',1,'disptab.h']]],
  ['pld_5fesc_5ffp',['plD_esc_fp',['../disptab_8h.html#a6fcba71f450d728d8431160ebf0f8db4',1,'disptab.h']]],
  ['pld_5finit_5ffp',['plD_init_fp',['../disptab_8h.html#a3ebd38ea7490efc133bf77c311592b00',1,'disptab.h']]],
  ['pld_5fline_5ffp',['plD_line_fp',['../disptab_8h.html#a2abe835972dc40271414432dfd64b4e4',1,'disptab.h']]],
  ['pld_5fpolyline_5ffp',['plD_polyline_fp',['../disptab_8h.html#a5832dd5b40a48140599b44dfc8dd49e4',1,'disptab.h']]],
  ['pld_5fstate_5ffp',['plD_state_fp',['../disptab_8h.html#a863e93dac9207f44a2b201f9e6277fb0',1,'disptab.h']]],
  ['pld_5ftidy_5ffp',['plD_tidy_fp',['../disptab_8h.html#a039b30e4cf4e9b48de0a677c51c0cc62',1,'disptab.h']]],
  ['pld_5fwait_5ffp',['plD_wait_fp',['../disptab_8h.html#a1c631eccaad7a5990a6ed66a22d43685',1,'disptab.h']]],
  ['pldefined_5fcallback',['PLDEFINED_callback',['../plplot_8h.html#a982cd67d3d379d7de3bcbfce81ed856e',1,'plplot.h']]],
  ['pldispatchinit',['PLDispatchInit',['../plcore_8h.html#a85d0beadd216060ffea5e6e8d97d9e19',1,'plcore.h']]],
  ['plf2eval_5fcallback',['PLF2EVAL_callback',['../plplot_8h.html#a6bbc73a3a54eb928358deb36c8357223',1,'plplot.h']]],
  ['plf2ops',['PLF2OPS',['../plplot_8h.html#a8073ceeb1a43c3988d0f750cbf080c1c',1,'plplot.h']]],
  ['plfill_5fcallback',['PLFILL_callback',['../plplot_8h.html#a5a9fe881883822700c765736ed5cbc23',1,'plplot.h']]],
  ['plflt',['PLFLT',['../plplot_8h.html#a245c0090f1fa5e95a4ed3522975dcbf3',1,'plplot.h']]],
  ['plflt_5ffe_5fpointer',['PLFLT_FE_POINTER',['../plplot_8h.html#abc0828b1dd38bb3139012de4329e3175',1,'plplot.h']]],
  ['plflt_5fmatrix',['PLFLT_MATRIX',['../plplot_8h.html#a67b918cc9af5885167a80fd9247f104a',1,'plplot.h']]],
  ['plflt_5fnc_5ffe_5fpointer',['PLFLT_NC_FE_POINTER',['../plplot_8h.html#a511843577d8f015e87bad347996d1549',1,'plplot.h']]],
  ['plflt_5fnc_5fmatrix',['PLFLT_NC_MATRIX',['../plplot_8h.html#a8c9260680120bb940f1674993e6475f5',1,'plplot.h']]],
  ['plflt_5fnc_5fscalar',['PLFLT_NC_SCALAR',['../plplot_8h.html#a284b03b374fffe9f3268acf953567d73',1,'plplot.h']]],
  ['plflt_5fnc_5fvector',['PLFLT_NC_VECTOR',['../plplot_8h.html#ac89ba8a98a4fc3dd1caad21b76002064',1,'plplot.h']]],
  ['plflt_5fvector',['PLFLT_VECTOR',['../plplot_8h.html#a5cacbcce57b8b6cd79709ab7369d1fc6',1,'plplot.h']]],
  ['plint',['PLINT',['../plplot_8h.html#ad703d3a4f671fdd34ec71f3480f6af2d',1,'plplot.h']]],
  ['plint64',['PLINT64',['../plplot_8h.html#a75b290585084690535ae97d74b07b570',1,'plplot.h']]],
  ['plint_5fnc_5fscalar',['PLINT_NC_SCALAR',['../plplot_8h.html#aa39c2fe094bf9b6a9f2c80ca1353441b',1,'plplot.h']]],
  ['plint_5fnc_5fvector',['PLINT_NC_VECTOR',['../plplot_8h.html#a54e8a0433cd80260a1c77f250f603937',1,'plplot.h']]],
  ['plint_5fvector',['PLINT_VECTOR',['../plplot_8h.html#a8a5cd9170553853e6ac277367d9f87b9',1,'plplot.h']]],
  ['pllabel_5ffunc_5fcallback',['PLLABEL_FUNC_callback',['../plplot_8h.html#a22f264304f9a43458c061818bc4a6b97',1,'plplot.h']]],
  ['plmapform_5fcallback',['PLMAPFORM_callback',['../plplot_8h.html#a91d34b63f01682659076c6bdba18e706',1,'plplot.h']]],
  ['plplotter',['PlPlotter',['../plplotter_8c.html#af28f8c51f905ee041775cb8488ccaf7b',1,'plplotter.c']]],
  ['plpointer',['PLPointer',['../plplot_8h.html#ae1d5cf832d1a16ecbacbf5eb4bf5e8f1',1,'plplot.h']]],
  ['pltr_5ffunc',['pltr_func',['../plplotluacLUA__wrap_8c.html#adb44115e765b5ccc525e1868df2d4446',1,'pltr_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adb44115e765b5ccc525e1868df2d4446',1,'pltr_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adb44115e765b5ccc525e1868df2d4446',1,'pltr_func():&#160;plplotcPYTHON_wrap.c']]],
  ['pltransform_5fcallback',['PLTRANSFORM_callback',['../plplot_8h.html#a8bb5098e1b354a706a2554d2ccb554a4',1,'plplot.h']]],
  ['pluint',['PLUINT',['../plplot_8h.html#a6d6b24fb8596cddc72a21a37cbda14e2',1,'plplot.h']]],
  ['plunicode',['PLUNICODE',['../plplot_8h.html#a1d3c883be63b6e7855f5bc7ad5212915',1,'plplot.h']]],
  ['plunicode_5fnc_5fscalar',['PLUNICODE_NC_SCALAR',['../plplot_8h.html#a44726b7856581214252163dbe1a130cd',1,'plplot.h']]],
  ['pt',['PT',['../plgridd_8c.html#a16e1ed82300e278c21da97ea77aee31c',1,'plgridd.c']]],
  ['py_5fssize_5ft',['Py_ssize_t',['../plplotcPYTHON__wrap_8c.html#a47424a8953c340f500027db7e6c00173',1,'plplotcPYTHON_wrap.c']]]
];
